@@ -87,15 +87,17 @@ class ConfigRun(metaclass=ExecutionSingleton):
         self.args = None
         self.environ = {}
 
-    def prepare_environment(self):
-        output = self.get_param('output.path', 'output_folder')
-        self.environ['output'] = output
-        self.environ['temp'] = os.path.join(output, 'temp')
-        self.environ['logs'] = os.path.join(output, 'outputs', 'logs')
 
     def set_args(self, args):
         self.args = args
-        self.prepare_environment()
+        output = self.get_param('output.path', 'output_folder')
+        if bool(args.customized_json) is True or str(args.customized_json) == 'True':
+            self.environ['logs'] = os.path.join(os.environ.get('FEATURES_PATH'), 'merge_report_logs')
+        else:
+            self.environ['logs'] = os.path.join(output, 'outputs', 'logs')
+        self.environ['output'] = output
+        self.environ['temp'] = os.path.join(output, 'temp')
+
 
     def set_env(self, key, value):
         self.environ[key] = value
