@@ -185,11 +185,9 @@ def launch_behavex():
             print("use merged json data: %s\\report_data.json" % os.environ.get('FEATURES_PATH'))
             with open("%s\\report_data.json" % os.environ.get('FEATURES_PATH'), 'r') as f:
                 json_reports = json.load(f)
-            for root, dirs, files in os.walk(os.path.join(os.environ.get('FEATURES_PATH'), 'merge_report_logs')):
-                for file in files:
-                    old_file_path = os.path.join(root, file)
-                    new_file_path = os.path.join(os.path.join(conf_mgr.get_param('output.path', 'output_folder'), 'outputs', 'logs'), file)
-                    shutil.copyfile(old_file_path, new_file_path)
+            folderpath = os.path.join(conf_mgr.get_param('output.path', 'output_folder'), 'outputs', 'logs')
+            shutil.rmtree(folderpath)
+            shutil.copytree(os.path.join(os.environ.get('FEATURES_PATH'), 'merge_report_logs'), folderpath)
         wrap_up_process_pools(process_pool, json_reports, multiprocess, scenario)
         time_end = time.time()
 
